.. _image_ref:

:mod:`nilearn.image`: Image Processing and Resampling Utilities
===============================================================

.. automodule:: nilearn.image
   :no-members:
   :no-inherited-members:

Functions
---------

.. currentmodule:: nilearn.image

.. autosummary::
   :toctree: generated/
   :template: function.rst

   binarize_img
   clean_img
   concat_imgs
   coord_transform
   copy_img
   crop_img
   get_data
   high_variance_confounds
   index_img
   iter_img
   largest_connected_component_img
   load_img
   math_img
   mean_img
   new_img_like
   resample_img
   resample_to_img
   reorder_img
   smooth_img
   swap_img_hemispheres
   threshold_img
